# Package Guides

These pages summarize the role of each Python package in the monorepo and point to the
generated API reference for the most important modules.

```{toctree}
:maxdepth: 1

axioms
engine
middleware
```
